/*
** Module   : SpaceField.java
** Abstract : outputs spaces to a stream
**
** Copyright (c) 2006-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ------------------------------Description----------------------------
** 001 GES 20060925   @29903 Created initial version which outputs spaces
**                           to a stream.
** 002 SIY 20071001   @35324 Changed inheritance. Made class suitable for 
**                           network transfers and for code reuse. 
**                           Ref: #35314
** 003 SIY 20071003   @35353 Header cleanup.
** 004 CA  20130308          Added missing c'tor, which receives a 4GL integer value.
** 005 OM  20130527          Added int64 support.
*/ 

package com.goldencode.p2j.util;

/**
 * Outputs spaces to a stream. 
 */
public class SpaceField
extends NullField
{
   /**
    * Default constructor (outputs a single space).
    */
   public SpaceField()
   {
   }
   
   /**
    * Constructor for an explicit number of spaces. If <code>num</code> is too large to be 
    * stored on short, it will be truncated automatically to 16 bits.
    *
    * @param    num
    *           The number of spaces to output.
    */
   public SpaceField(int num)
   {
      super(num);
   }
   
   /**
    * Constructor for an explicit number of spaces. If <code>num</code> is too large to be 
    * stored on short, it will be truncated automatically to 16 bits.
    *
    * @param    num
    *           The number of spaces to output.
    */
   public SpaceField(int64 num)
   {
      if (num.isUnknown())
      {
         ErrorManager.recordOrThrowError(564, "Unable to evaluate expression for PUT statement");
         return;
      }

      setNum(num.intValue());
      setExplicit(true);
   }

   /**
    * Renders the contained field definition to the given stream.
    *
    * @param    out
    *           The stream to which the field should be rendered.
    */
   public void output(Stream out)
   throws ErrorConditionException
   {
      if (isExplicit())
      {
         out.putSpace(getNum());
      }
      else
      {
         out.putSpace();
      }
   }
}
